﻿using Infragistics.Olap;
using Infragistics.Olap.FlatData;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Linq.Expressions;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace XamPivotGridFlatDataInCode
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public static FlatDataSource DataSource { get; set; }

        public static List<DistributorInventory> Items { get; set; }

        public MainWindow()
        {
            InitializeComponent();

            LoadData();

            pivotgrid.DataSource = DataSource;
        }

        public static void LoadData()
        {           
           
                var items = new[]
                {
                    "Carlsberg bottle 0,5",
                    "Carlsbers mug 0,5",
                    "Baltica №3 bottle 0,5"
                };
                var distributors = new[]
                {
                    "ООО \"Pivo\"",
                    "ООО \"Pay at the end\""
                };
                var addresses = new[]
                {
                    "Address 1",
                    "Address 2",
                    "Address 3",
                    "Address 4",
                    "Address 5"
                };
                var dates = Enumerable.Range(0, 12).Select(i => DateTime.Now.AddDays(-7 * i)).ToList();

                Items = (from distributor in distributors
                         from address in addresses
                         from item in items
                         from date in dates
                         select new DistributorInventory
                         {
                             Distributor = distributor,
                             Address = address,
                             Item = item,
                             Date = date
                         }).ToList();
            

            RefreshDataSource();
        }

        private static void RefreshDataSource()
        {
            DataSource = new FlatDataSource
            {
                Cube = DataSourceBase.GenerateInitialCube("DistributorInventory"),
                Rows = DataSourceBase.GenerateInitialItems("[Distributor].[Distributor]"),
                Columns = DataSourceBase.GenerateInitialItems("[Date].[Date]"),
                Measures = DataSourceBase.GenerateInitialItems("Value"),
                Filters = DataSourceBase.GenerateInitialItems("[WeekText].[WeekText]")
            };

            var cubeMetadata = new CubeMetadata
            {
                DisplayName = "Cube",
                DataTypeFullName = typeof(DistributorInventory).FullName
            };
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata
            {
                SourcePropertyName = "Value",
                DisplayName = "Inventory",
            });

            DataSource.PreserveMembersOrder = false;

            DataSource.CubesSettings.Add(cubeMetadata);
            var datesHierarchy = new HierarchyDescriptor<DistributorInventory>(p => p.Date) { HierarchyDisplayName = "Date" };
            datesHierarchy.AddLevel(p => p.MonthText, "Month");
            //datesHierarchy.AddLevel(p => p.WeekText, "Week");

            Expression<Func<DistributorInventory, int>> orderByExpression = d => d.Date.Month;
            datesHierarchy.LevelDescriptors[0].OrderByKeyExpression = orderByExpression;
            DataSource.AddHierarchyDescriptor(datesHierarchy);

            

            var itemsHierarchy = new HierarchyDescriptor<DistributorInventory>(p => p.Distributor) { HierarchyDisplayName = "Distributor" };
            itemsHierarchy.AddLevel(p => p.Distributor, "Distributor");
            itemsHierarchy.AddLevel(p => p.Address, "Address");
            itemsHierarchy.AddLevel(p => p.Item, "SKU");
            DataSource.AddHierarchyDescriptor(itemsHierarchy);

           

            DataSource.ItemsSource = Items;

            
        }
    }
}
